
/*
REPLICATION DATA FOR 

"RECONCILING CLIMATE-CONFLICT RESULTS IN KENYA"

CEGA Working Paper 032 (2013)

Authors: SOLOMON HSIANG, MARSHALL BURKE, EDWARD MIGUEL
*/

/*
Data is original data from Theisen (2012). Code is modified from original code, but variable names and replication commands (as well as comments) are retained.
 
Original comments use the "*" line prefix
Our comments use the "//" line prefix

*/
set more off

/*Change this to reflect your working directory */
cd "C:\Users\Elisa Cascardi\Desktop\Data Replication Sets\Reconciling Temp Conflict Results_Replication\replication_file"

use "Theisen_2012_data.dta", clear
cap log using reconciling_log, replace

// Make a plot the erroneous coding (Figure 1)

gen stdevprec2_correct = stdevprec*stdevprec 
gen stdevtemp2_correct = stdevtemp*stdevtemp

sort stdevprec
tw (line precpossq stdevprec, lcolor(gs10))(line stdevprec2_correct stdevprec, lcolor(black) lwidth(thick)), legend(lab(1 "Thiesen 2012") lab(2 "Corrected")) xlabel(-2 0 2) xtit("Standardized precipitation") tit("Standardized precipitation squared") saving(prec_correction.gph, replace)

sort stdevtemp
tw (line temposq stdevtemp, lcolor(gs10))(line stdevtemp2_correct stdevtemp, lcolor(black) lwidth(thick)), legend(lab(1 "Thiesen 2012") lab(2 "Corrected")) xlabel(-2 0 2) xtit("Standardized temperature") tit("Standardized temperature squared") saving(temp_correction.gph, replace)

graph combine prec_correction.gph temp_correction.gph
graph export corrected_vars.pdf, replace

// computing the constant that was used to offset the data
gen C_temp = sqrt(temposq)-stdevtemp 
gen C_precip = sqrt(precpossq)-stdevprec 

//----------------------------PANEL I - CONFLICT ONSET ("CONFLICT")

*Fixed effects models of climate variability
iis (et_id)

*TABLE 1 OLS fixed effects of climate factors, using previous year's spatial lag - squared term based on a non-negative version of the deviation measure
*Model 1 
xtreg  conflict stdevprec precpossq l_sptllag_corr onehlfevnt_corr trend y1990  y1992 y1993 y1994 y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 if year < 2005, fe cl(et_id)
outreg2 using panel1, replace dec(5) excel ct(model 1)

// correction
xtreg  conflict c.stdevprec##c.stdevprec   l_sptllag_corr onehlfevnt_corr trend y1990  y1992 y1993 y1994 y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 if year < 2005, fe cl(et_id)
outreg2 using panel1,  dec(5) excel ct(corrected)

*Model 5
xtreg  conflict stdevtemp temposq l_sptllag_corr onehlfevnt_corr trend y1990  y1992 y1993 y1994 y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 if year < 2005, fe cl(et_id)
outreg2 using panel1,  dec(5) excel ct(Model 5)

//computing corrected coeff using the original estimate
nlcom _b[stdevtemp]+2*_b[temposq]*2.395948

//corrected estimate
xtreg  conflict  c.stdevtemp##c.stdevtemp  l_sptllag_corr onehlfevnt_corr trend y1990  y1992 y1993 y1994 y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 if year < 2005, fe cl(et_id)
outreg2 using panel1,  dec(5) excel ct(corrected)


//linearized model
xtreg  conflict stdevtemp stdevprec trend y1990  y1992 y1993 y1994 y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 if year < 2005, fe cl(et_id)
outreg2 using panel1,  dec(5) excel ct(Linear)

//quadratic model
xtreg  conflict c.stdevtemp##c.stdevtemp c.stdevprec##c.stdevprec  trend y1990  y1992 y1993 y1994 y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 if year < 2005, fe cl(et_id)
outreg2 using panel1,  dec(5) excel ct(quadratic)


//----------------------------Panel II - INCIDENCE ("EVENTS")

*Fixed effects models of climate variability
iis (et_id)

*TABLE 2 OLS fixed effects of climate factors, using previous year's spatial lag - squared term based on a non-negative version of the deviation measure
*Model 7
xtreg  event_corr stdevprec precpossq l_sptllag_corr onehlfevnt_corr trend y1990  y1992 y1993 y1994 y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 if year < 2005, fe cl(et_id)
outreg2 using panel2, replace dec(5) excel ct(model 7)

//corrected
xtreg  event_corr c.stdevprec##c.stdevprec  l_sptllag_corr onehlfevnt_corr trend y1990  y1992 y1993 y1994 y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 if year < 2005, fe cl(et_id)
outreg2 using panel2,  dec(5) excel ct(corrected)

*Model 11
xtreg  event_corr stdevtemp temposq l_sptllag_corr onehlfevnt_corr trend y1990  y1992 y1993 y1994 y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 if year < 2005, fe cl(et_id)
outreg2 using panel2,  dec(5) excel ct(model 11)

//computing corrected coeff using the original estimate
nlcom _b[stdevtemp]+2*_b[temposq]*2.395948

//corrected estimate
xtreg  event_corr c.stdevtemp##c.stdevtemp  l_sptllag_corr onehlfevnt_corr trend y1990  y1992 y1993 y1994 y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 if year < 2005, fe cl(et_id)
outreg2 using panel2,  dec(5) excel ct(corrected)

//linearized model
xtreg  event_corr  stdevprec stdevtemp  l_sptllag_corr onehlfevnt_corr trend y1990  y1992 y1993 y1994 y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 if year < 2005, fe cl(et_id)
outreg2 using panel2,  dec(5) excel ct(linear)

//quadratic model
xtreg  event_corr  c.stdevprec##c.stdevprec c.stdevtemp##c.stdevtemp  l_sptllag_corr onehlfevnt_corr trend y1990  y1992 y1993 y1994 y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 if year < 2005, fe cl(et_id)
outreg2 using panel2,  dec(5) excel ct(quadratic)




